[Commits] [svn:einsteintoolkit] IllinoisGRMHD/trunk/src/ (Rev. 11)

zachetie at gmail.com zachetie at gmail.com
Tue Oct 15 15:31:57 CDT 2013


User: zetienne
Date: 2013/10/15 03:31 PM

Modified:
 /trunk/src/
  Lorenz_psi6phi_rhs__add_gauge_terms_to_A_i_rhs.C, driver_evaluate_MHD_rhs.C, evaluate_MHD_rhs_headers.h

Log:
 Fixed variable names (gij -> gtij, Aij,trK -> kij) for compatibility with ADMBase. Next step: fix gupij & write ADM->BSSN translation routine

File Changes:

Directory: /trunk/src/
======================

File [modified]: Lorenz_psi6phi_rhs__add_gauge_terms_to_A_i_rhs.C
Delta lines: +0 -1
===================================================================
--- trunk/src/Lorenz_psi6phi_rhs__add_gauge_terms_to_A_i_rhs.C	2013-10-14 05:38:20 UTC (rev 10)
+++ trunk/src/Lorenz_psi6phi_rhs__add_gauge_terms_to_A_i_rhs.C	2013-10-15 20:31:57 UTC (rev 11)
@@ -151,7 +151,6 @@
 	shiftz_iphjphkph[index]=shiftz_iphjphkphL;
       }
 
-  // This loop requires two additional ghostzones in every direction. Hence the following loop definition:
 #pragma omp parallel for
   for(int k=3;k<ext[2]-3;k++) for(int j=3;j<ext[1]-3;j++) for(int i=3;i<ext[0]-3;i++) {
 	int index = CCTK_GFINDEX3D(cctkGH,i,j,k);

File [modified]: driver_evaluate_MHD_rhs.C
Delta lines: +6 -12
===================================================================
--- trunk/src/evaluate_MHD_rhs_headers.h	2013-10-14 05:38:20 UTC (rev 10)
+++ trunk/src/evaluate_MHD_rhs_headers.h	2013-10-15 20:31:57 UTC (rev 11)
@@ -60,11 +60,11 @@
                                   eos_struct &eosi,gf_and_gz_struct *in_prims,gf_and_gz_struct *out_prims_r,gf_and_gz_struct *out_prims_l,
                                   double *ftilde_gf,double *temporary);
 
-void compute_tau_rhs_extrinsic_curvature_terms_and_TUPmunu
+void initialize_hydro_rhss__compute_tau_rhs_extrinsic_curvature_terms_and_TUPmunu
 (const cGH *cctkGH,int *ext,double *dX,double **metric,gf_and_gz_struct *prims,double **TUPmunu,double *u0,eos_struct &eos,
  double *gupxy,double *gupxz,double *gupyz,
  double *Axx,double *Axy,double *Axz,double *Ayy,double *Ayz,double *Azz,double *trK,
- double *tau_rhs);
+ double *rho_star_rhs,double *tau_rhs,double *st_x_rhs,double *st_y_rhs,double *st_z_rhs);
 void A_i_rhs_no_gauge_terms(int &A_dirn, const cGH *cctkGH,int *ext,gf_and_gz_struct *out_prims_r,gf_and_gz_struct *out_prims_l,
                             double *phi_interped,double *cmax_1,double *cmin_1,double *cmax_2,double *cmin_2, double *A3_rhs);
 



More information about the Commits mailing list
--- trunk/src/driver_evaluate_MHD_rhs.C	2013-10-14 05:38:20 UTC (rev 10)
+++ trunk/src/driver_evaluate_MHD_rhs.C	2013-10-15 20:31:57 UTC (rev 11)
@@ -149,11 +149,11 @@
   // Here, we:
   // 1) Compute tau_rhs extrinsic curvature terms, and
   // 2) Compute TUPmunu.
-  // This function is housed in the file: "compute_tau_rhs_extrinsic_curvature_terms_and_TUPmunu.C"
-  compute_tau_rhs_extrinsic_curvature_terms_and_TUPmunu(cctkGH,cctk_lsh,dX,metric,in_prims,TUPmunu,u0,eos,
-							gupxy,gupxz,gupyz,
-							Axx,Axy,Axz,Ayy,Ayz,Azz,trK,
-							tau_rhs};
+  // This function is housed in the file: "initialize_hydro_rhss__compute_tau_rhs_extrinsic_curvature_terms_and_TUPmunu.C"
+  initialize_hydro_rhss__compute_tau_rhs_extrinsic_curvature_terms_and_TUPmunu(cctkGH,cctk_lsh,dX,metric,in_prims,TUPmunu,u0,eos,
+									       gupxy,gupxz,gupyz,
+									       Axx,Axy,Axz,Ayy,Ayz,Azz,trK,
+									       rho_star_rhs,tau_rhs,st_x_rhs,st_y_rhs,st_z_rhs);
   int flux_dirn;
   flux_dirn=1;
   // First compute ftilde, which is used for flattening left and right face values
@@ -189,8 +189,6 @@
   // This function is housed in the file: "reconstruct_set_of_prims_PPM.C"
   reconstruct_set_of_prims_PPM(cctkGH,cctk_lsh,flux_dirn,num_prims_to_reconstruct,which_prims_to_reconstruct,
 			       eos,in_prims,out_prims_r,out_prims_l,ftilde_gf,temporary);
-  //Right and left face values of BI_CENTER are used in mhdflux computation (first to compute b^a).
-  //   Instead of reconstructing, we simply set B^x face values to be consistent with BX_STAGGER.
 #pragma omp parallel for
   for(int k=0;k<cctk_lsh[2];k++) for(int j=0;j<cctk_lsh[1];j++) for(int i=0;i<cctk_lsh[0];i++) {
 	int index=CCTK_GFINDEX3D(cctkGH,i,j,k), indexim1=CCTK_GFINDEX3D(cctkGH,i-1+(i==0),j,k);
@@ -265,8 +263,6 @@
   // This function is housed in the file: "reconstruct_set_of_prims_PPM.C"
   reconstruct_set_of_prims_PPM(cctkGH,cctk_lsh,flux_dirn,num_prims_to_reconstruct,which_prims_to_reconstruct, 
 			       eos,in_prims,out_prims_r,out_prims_l,ftilde_gf,temporary);
-  //Right and left face values of BI_CENTER are used in mhdflux computation (first to compute b^a).
-  //   Instead of reconstructing, we simply set B^y face values to be consistent with BY_STAGGER.
 #pragma omp parallel for
   for(int k=0;k<cctk_lsh[2];k++) for(int j=0;j<cctk_lsh[1];j++) for(int i=0;i<cctk_lsh[0];i++) {
 	int index=CCTK_GFINDEX3D(cctkGH,i,j,k), indexjm1=CCTK_GFINDEX3D(cctkGH,i,j-1+(j==0),k);
@@ -362,8 +358,6 @@
   // This function is housed in the file: "reconstruct_set_of_prims_PPM.C"
   reconstruct_set_of_prims_PPM(cctkGH,cctk_lsh,flux_dirn,num_prims_to_reconstruct,which_prims_to_reconstruct, 
 			       eos,in_prims,out_prims_r,out_prims_l,ftilde_gf,temporary);
-  //Right and left face values of BI_CENTER are used in mhdflux computation (first to compute b^a).
-  //   Instead of reconstructing, we simply set B^z face values to be consistent with BZ_STAGGER.
 #pragma omp parallel for
   for(int k=0;k<cctk_lsh[2];k++) for(int j=0;j<cctk_lsh[1];j++) for(int i=0;i<cctk_lsh[0];i++) {
 	int index=CCTK_GFINDEX3D(cctkGH,i,j,k), indexkm1=CCTK_GFINDEX3D(cctkGH,i,j,k-1+(k==0));
@@ -509,7 +503,7 @@
 //    convenient to edit a 600 line file than an 1800 line file, so I'd prefer to leave this unconventional structure
 //    alone.
 #include "reconstruct_set_of_prims_PPM.C"
-#include "compute_tau_rhs_extrinsic_curvature_terms_and_TUPmunu.C"
+#include "initialize_hydro_rhss__compute_tau_rhs_extrinsic_curvature_terms_and_TUPmunu.C"
 #include "add_fluxes_and_source_terms_to_hydro_rhss.C"
 #include "mhdflux.C"
 #include "A_i_rhs_no_gauge_terms.C"

File [modified]: evaluate_MHD_rhs_headers.h
Delta lines: +2 -2
===================================================================